@@ -9,7 +9,7 @@ BEGIN {
 	@ISA=qw(Exporter);
 	@EXPORT=qw( );
 	@EXPORT_OK=qw( &error $VERBOSE $LEVELMAX $VERSION );
-	$VERSION='0.88';
+	$VERSION='0.89';
 	sub VERSION {
 		(my $me, my $askedver)=@_;
 		$VERSION=~s/(.*)_\d+/$1/;
@@ -264,7 +264,7 @@ sub wr {
 
 # Header building!!
 #####################################
-	if ($_[0] eq $args{'-n'}) {
+	if (defined $_[0] and $_[0] eq $args{'-n'}) {
 		shift;
 		$nocr=1;
 	} else {
